=== modified file 'NEWS'
--- NEWS	2011-12-11 17:14:12 +0000
+++ NEWS	2011-12-20 16:47:38 +0000
@@ -1,5 +1,10 @@
 0.104.0	UNRELEASED
 
+ BUG FIXES
+
+  * Fix compatibility with newer versions of gir-gtk which don't allow
+    None in STRING columns of ListStores. (Jelmer Vernooij)
+
 0.103.0	2011-12-11
 
  FEATURES

=== modified file 'commit.py'
--- commit.py	2011-12-20 16:16:57 +0000
+++ commit.py	2011-12-20 16:47:38 +0000
@@ -24,6 +24,7 @@
 from bzrlib import (
     bencode,
     errors,
+    osutils,
     trace,
     )
 from bzrlib.plugins.gtk.dialog import question_dialog
@@ -92,7 +93,7 @@
 def _sanitize_and_decode_message(utf8_message):
     """Turn a utf-8 message into a sanitized Unicode message."""
     fixed_newline = _newline_variants_re.sub('\n', utf8_message)
-    return fixed_newline.decode('utf-8')
+    return osutils.safe_unicode(fixed_newline)
 
 
 class CommitDialog(Gtk.Dialog):
@@ -186,7 +187,7 @@
 
         all_enabled = (self._selected is None)
         # The first entry is always the 'whole tree'
-        all_iter = store.append([None, None, all_enabled, 'All Files', '', ''])
+        all_iter = store.append(["", "", all_enabled, 'All Files', '', ''])
         initial_cursor = store.get_path(all_iter)
         # should we pass specific_files?
         self._wt.lock_read()
@@ -443,7 +444,7 @@
                                      self._on_treeview_files_cursor_changed)
 
     def _toggle_commit(self, cell, path, model):
-        if model[path][0] is None: # No file_id means 'All Files'
+        if model[path][0] == "": # No file_id means 'All Files'
             new_val = not model[path][2]
             for node in model:
                 node[2] = new_val
@@ -571,10 +572,10 @@
         if selection is not None:
             path, display_path = model.get(selection, 1, 3)
             self._diff_label.set_text(_i18n('Diff for ') + display_path)
-            if path is None:
+            if path == "":
                 self._diff_view.show_diff(None)
             else:
-                self._diff_view.show_diff([path.decode('UTF-8')])
+                self._diff_view.show_diff([osutils.safe_unicode(path)])
             self._update_per_file_info(selection)
 
     def _on_accel_next(self, accel_group, window, keyval, modifier):
@@ -592,7 +593,7 @@
             # selected. Either way, select All Files, and jump to the global
             # commit message.
             self._treeview_files.set_cursor(
-                Gtk.TreePath(path=0), None, False)
+                Gtk.TreePath(path=0), "", False)
             self._global_message_text_view.grab_focus()
         else:
             # Set the cursor to this entry, and jump to the per-file commit
@@ -617,7 +618,7 @@
         self._save_current_file_message()
         text_buffer = self._file_message_text_view.get_buffer()
         file_id, display_path, message = self._files_store.get(selection, 0, 3, 5)
-        if file_id is None: # Whole tree
+        if file_id == "": # Whole tree
             self._file_message_expander.set_label(_i18n('File commit message'))
             self._file_message_expander.set_expanded(False)
             self._file_message_expander.set_sensitive(False)
@@ -640,13 +641,13 @@
         files = []
         records = iter(self._files_store)
         rec = records.next() # Skip the All Files record
-        assert rec[0] is None, "Are we skipping the wrong record?"
+        assert rec[0] == "", "Are we skipping the wrong record?"
 
         file_info = []
         for record in records:
             if self._commit_all_changes or record[2]:# [2] checkbox
-                file_id = record[0] # [0] file_id
-                path = record[1]    # [1] real path
+                file_id = osutils.safe_utf8(record[0]) # [0] file_id
+                path = osutils.safe_utf8(record[1])    # [1] real path
                 # [5] commit message
                 file_message = _sanitize_and_decode_message(record[5])
                 files.append(path.decode('UTF-8'))

=== modified file 'commitmsgs.py'
--- commitmsgs.py	2011-12-20 16:16:57 +0000
+++ commitmsgs.py	2011-12-20 16:47:38 +0000
@@ -59,8 +59,11 @@
         for fi in file_info:
             file_message = fi['message']
             if file_message:
-                file_messages[fi['file_id']] = file_message # utf-8 strings
+                file_id = fi['file_id']
+                assert type(file_id) is str
+                file_messages[file_id] = file_message # utf-8 strings
         for k,v in file_messages.iteritems():
+            assert type(k) is str
             try:
                 self.file_messages[k] = v + '\n******\n' + self.file_messages[k]
             except KeyError:

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2011-12-20 16:16:57 +0000
+++ tests/test_commit.py	2011-12-20 16:47:38 +0000
@@ -296,7 +296,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'added'),
                           ('b-id', 'b', True, 'b/', 'added'),
                           ('c-id', 'b/c', True, 'b/c', 'added'),
@@ -313,7 +313,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('b-id', 'd', True, 'b/ => d/', 'renamed'),
                           ('a-id', 'd/a', True, 'a => d/a', 'renamed'),
                          ], values)
@@ -328,7 +328,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'modified'),
                          ], values)
 
@@ -348,7 +348,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('b-id', 'd', True, 'b/ => d/', 'renamed'),
                           ('a-id', 'd/a', True, 'a => d/a', 'renamed and modified'),
                           ('c-id', 'd/c', True, 'd/c', 'modified'),
@@ -371,7 +371,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('a-id', 'a', True, 'a => a/', 'kind changed'),
                           # ('b-id', 'c', True, 'b => c/', 'renamed and modified'),
                          ], values)
@@ -387,7 +387,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, True, 'All Files', ''),
+        self.assertEqual([("", "", True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'removed'),
                           ('b-id', 'b', True, 'b/', 'removed'),
                          ], values)
@@ -402,7 +402,7 @@
 
         dlg = commit.CommitDialog(tree, selected='a')
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([(None, None, False, 'All Files', ''),
+        self.assertEqual([("", "", False, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'added'),
                           ('b-id', 'b', False, 'b/', 'added'),
                          ], values)
@@ -586,7 +586,7 @@
         tree.add(['a', 'b'], ['a-id', 'b-id'])
 
         dlg = commit.CommitDialog(tree)
-        self.assertEqual([(None, None, True),
+        self.assertEqual([("", "", True),
                           ('a-id', 'a', True),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
@@ -601,26 +601,26 @@
 
         # Toggle a single entry should set just that entry to False
         dlg._toggle_commit(None, 1, dlg._files_store)
-        self.assertEqual([(None, None, True),
+        self.assertEqual([("", "", True),
                           ('a-id', 'a', False),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         # Toggling the main entry should set all entries
         dlg._toggle_commit(None, 0, dlg._files_store)
-        self.assertEqual([(None, None, False),
+        self.assertEqual([("", "", False),
                           ('a-id', 'a', False),
                           ('b-id', 'b', False),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         dlg._toggle_commit(None, 2, dlg._files_store)
-        self.assertEqual([(None, None, False),
+        self.assertEqual([("", "", False),
                           ('a-id', 'a', False),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         dlg._toggle_commit(None, 0, dlg._files_store)
-        self.assertEqual([(None, None, True),
+        self.assertEqual([("", "", True),
                           ('a-id', 'a', True),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])

